==> nextcloud-16.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/mk.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Настана грешка при генерирање на вашите резервни кодови",
    "{name} backup codes" : "{name} резервни кодови",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Овие се вашите резервни кодови. Ве молиме зачувајте ги и/или испечатете ги бидејќи нема да бидете во можност да ги видите повторно",
    "Save backup codes" : "Зачувај ги резервните кодови",
    "Print backup codes" : "Печати ги резевните кодови",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервни кодови се генерирани. Искористени се {used} од {total} кодови.",
    "Regenerate backup codes" : "Генерирај повторно резервни кодови",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Доколку генерирате повторно резервни кодови, старите кодови нема да бидат во употреба.",
    "Generate backup codes" : "Генерирај резервни кодови",
    "You created two-factor backup codes for your account" : "Вие креиравте резервни кодови за двофакторна автентификација на вашата сметка",
    "Second-factor backup codes" : "Резервни кодови за двофакторна автентификација",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Вие имате активирано двофакторна автентикација но немате генерирано резервни кодови. Тие се потребни за во случај да го изгубите пристапот до вториот фактор.",
    "Backup code" : "Резервен код",
    "Use backup code" : "Искористи резервен код",
    "Two factor backup codes" : "Резервни кодови за двофакторна автентификација",
    "A two-factor auth backup codes provider" : "Провајдер за резервни кодови за двофакторна автентификација",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Искористи еден од резервните кодови што ги зачувавте кога активиравте двофакторна автентикација.",
    "Submit" : "Испрати",
    "Nextcloud backup codes" : "Nextcloud резервни кодови",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Вие имате активирано двофакторна автентикација но немате генерирано резервни кодови за пристап. Генерирајте кодови и зачувајте ги на безбедно место за да не го изгубите пристапот до вашата сметка."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-18.0.8.tgz: nextcloud/apps/twofactor_backupcodes/l10n/mk.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Креиравте резервни кодови за двофакторна автентификација на вашата сметка",
    "Second-factor backup codes" : "Резервни кодови за двофакторна автентификација",
    "Generate backup codes" : "Генерирај резервни кодови",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Имате активирано двофакторна автентикација но немате генерирано резервни кодови. Тие се потребни за во случај да го изгубите пристапот до вториот фактор.",
    "Backup code" : "Резервен код",
    "Use backup code" : "Искористи резервен код",
    "Two factor backup codes" : "Резервни кодови за двофакторна автентификација",
    "A two-factor auth backup codes provider" : "Провајдер за резервни кодови за двофакторна автентификација",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервни кодови се генерирани. Искористени се {used} од {total} кодови.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Ова се вашите резервни кодови. Ве молиме зачувајте ги и/или испечатете ги бидејќи нема да бидете во можност да ги видите повторно",
    "Save backup codes" : "Зачувај ги резервните кодови",
    "Print backup codes" : "Печати ги резевните кодови",
    "Regenerate backup codes" : "Генерирај повторно резервни кодови",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Доколку генерирате повторно резервни кодови, старите кодови нема да бидат во употреба.",
    "An error occurred while generating your backup codes" : "Настана грешка при генерирање на вашите резервни кодови",
    "{name} backup codes" : "{name} резервни кодови",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Искористи еден од резервните кодови што ги зачувавте кога активиравте двофакторна автентикација.",
    "Submit" : "Испрати",
    "function" : "функција",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"]
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
